Free Energy Minimization
========================

Quick Start
-----------

Installation
~~~~~~~~~~~~

- To install ``fem``:

  .. code-block:: sh

     pip install fem

  .. note:: This package requires a fortran compiler to compile an external module; a popular, free choice is gfortran. This package also depends on the the lapack development files.


- Load ``fem`` in your Python script:

  .. code-block:: python

     import fem

Interactive notebook
~~~~~~~~~~~~~~~~~~~~

Launch an interactive Jupyter notebook using Binder to run and edit the examples in the documentation:

.. image:: https://mybinder.org/badge.svg
   :target: https://mybinder.org/v2/gh/joepatmckenna/fem/master?filepath=doc%2Fnotebooks

Links
-----

Online documentation:
    http://joepatmckenna.github.io/fem

Source code repository:
    https://github.com/joepatmckenna/fem

Python package index:
    https://pypi.python.org/pypi/fem
